import React, { MutableRefObject, useRef } from 'react';
import { App, Button, Space } from 'antd';
import { ActionType, ModalForm, ProFormInstance, ProFormText } from '@ant-design/pro-components';
import { nanoid } from 'nanoid';
import { addApp } from '@/services/api/app';
import { whitespaceForbidden } from '@/constants/rules';

/** 添加应用组件 */
const AddApp: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
}> = ({ actionRef }) => {
  const formRef = useRef<ProFormInstance>();
  const { message } = App.useApp();
  /** 提交数据 */
  const onFinish = async (values: any) => {
    await addApp(values);
    message.success('添加成功');
    actionRef.current?.reload();
    return true;
  };

  /** 生成id */
  const generateId = () => {
    formRef?.current?.setFieldsValue({
      appId: nanoid(),
    });
  };

  return (
    <ModalForm
      title="添加应用"
      onFinish={onFinish}
      trigger={
        <Button type="primary" onClick={() => setTimeout(() => generateId(), 100)}>
          添加
        </Button>
      }
      formRef={formRef}
    >
      <ProFormText
        name="appName"
        label="应用名称"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
        width={'lg'}
      />
      <Space>
        <ProFormText
          name="appId"
          label="appId"
          rules={[
            {
              required: true,
            },
            whitespaceForbidden,
          ]}
          width={'lg'}
        />
        <Button type="primary" onClick={generateId}>
          生成appId
        </Button>
      </Space>
    </ModalForm>
  );
};

export default AddApp;
