import { App, Button, Popconfirm } from 'antd';
import type { MutableRefObject } from 'react';
import React from 'react';
import { ActionType } from '@ant-design/pro-components';
import { addAppRobot } from '@/services/api/appRobot';

/** 删除应用机器人组件 */
const AddAppRobot: React.FC<{
  /** 打开关闭的事件 */
  setOpen: (v: boolean) => void;
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 应用编码 */
  appId: string;
  /** 机器人编码列表 */
  robotCodes: string[];
}> = ({ setOpen, actionRef, appId, robotCodes }) => {
  const { message } = App.useApp();

  const onConfirm = async () => {
    try {
      await addAppRobot({ appId, robotCodes });
      message.success('添加成功');
      actionRef.current?.reload();
      actionRef.current?.clearSelected?.();
      setOpen(false);
      return Promise.resolve();
    } catch (e) {
      return Promise.reject();
    }
  };

  return (
    <Popconfirm title="确定添加？" onConfirm={onConfirm}>
      <Button type={'primary'}>添加</Button>
    </Popconfirm>
  );
};

export default AddAppRobot;
