import React, { MutableRefObject, useRef } from 'react';
import { App, Button } from 'antd';
import { ActionType, ModalForm, ProFormInstance, ProFormText } from '@ant-design/pro-components';
import { whitespaceForbidden } from '@/constants/rules';
import { addAppRobotCommand } from '@/services/api/appRobotCommand';

/** 添加应用机器人命令组件 */
const AddAppRobotCommand: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 应用编码 */
  appId: string;
  /** 机器人编码 */
  robotCode: string;
}> = ({ actionRef, appId, robotCode }) => {
  const formRef = useRef<ProFormInstance>();
  const { message } = App.useApp();
  /** 提交数据 */
  const onFinish = async (values: any) => {
    await addAppRobotCommand({ ...values, appId, robotCode });
    message.success('添加成功');
    actionRef.current?.reload();
    return true;
  };

  return (
    <ModalForm
      title="添加命令"
      onFinish={onFinish}
      trigger={<Button type="primary">添加</Button>}
      formRef={formRef}
    >
      <ProFormText
        name="command"
        label="命令"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
      />
      <ProFormText
        name="url"
        label="url"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
      />
      <ProFormText name="description" label="说明" />
    </ModalForm>
  );
};

export default AddAppRobotCommand;
