import React, { MutableRefObject, useRef } from 'react';
import { App, Button, Space } from 'antd';
import {
  ActionType,
  ModalForm,
  ProFormDigit,
  ProFormInstance,
  ProFormText,
} from '@ant-design/pro-components';
import { nanoid } from 'nanoid';
import { addAppSftp } from '@/services/api/appSftp';
import { whitespaceForbidden } from '@/constants/rules';

/** 添加sftp组件 */
const AddAppSftp: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 应用编码 */
  appId: string;
}> = ({ actionRef, appId }) => {
  const formRef = useRef<ProFormInstance>();
  const { message } = App.useApp();
  /** 提交数据 */
  const onFinish = async (values: any) => {
    await addAppSftp({ ...values, appId });
    message.success('添加成功');
    actionRef.current?.reload();
    return true;
  };

  /** 生成id */
  const generateId = () => {
    formRef?.current?.setFieldsValue({
      sftpId: nanoid(),
    });
  };

  return (
    <ModalForm
      title="添加sftp"
      onFinish={onFinish}
      trigger={
        <Button type="primary" onClick={() => setTimeout(() => generateId(), 100)}>
          添加
        </Button>
      }
      formRef={formRef}
    >
      <Space>
        <ProFormText
          name="sftpId"
          label="sftpId"
          rules={[
            {
              required: true,
            },
            whitespaceForbidden,
          ]}
          width={'lg'}
        />
        <Button type="primary" onClick={generateId}>
          生成sftpId
        </Button>
      </Space>
      <ProFormText
        name="host"
        label="ip"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
        width={'lg'}
      />
      <ProFormDigit
        name={'port'}
        label={'端口'}
        min={0}
        max={65535}
        fieldProps={{ precision: 0 }}
        rules={[{ required: true }]}
        width={'lg'}
      />
      <ProFormText
        name="username"
        label="用户名"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
        width={'lg'}
      />
      <ProFormText
        name="password"
        label="密码"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
        width={'lg'}
      />
    </ModalForm>
  );
};

export default AddAppSftp;
