import { ActionType, ProColumns, ProTable } from '@ant-design/pro-components';
import React, { MutableRefObject, useRef } from 'react';
import { Modal, Table } from 'antd';
import { listAvailableRobot } from '@/services/api/appRobot';
import AddAppRobot from '@/pages/AppManage/components/AddAppRobot';

type TableListItem = API.ListAvailableRobotVo;

/** 应用机器人管理组件 */
const AvailableRobot: React.FC<{
  /** 受控的打开关闭 */
  open: boolean;
  /** 打开关闭的事件 */
  setOpen: (v: boolean) => void;
  /** Table action 的引用，便于自定义触发 */
  parentActionRef: MutableRefObject<ActionType | undefined>;
  /** 应用编码 */
  appId: string;
}> = ({ open, setOpen, parentActionRef, appId }) => {
  // Table action 的引用，便于自定义触发
  const actionRef = useRef<ActionType>();

  /**
   * 获取数据
   * @param params 参数
   * @param sort 排序
   */
  const getDataSource = async (params: any, sort: any) => {
    const res = await listAvailableRobot({
      ...params,
      sort,
      appId,
    });
    return Promise.resolve({
      success: true,
      data: res?.data?.list,
      total: res?.data?.total,
    });
  };

  // 表格列的配置描述
  const columns: ProColumns<TableListItem>[] = [
    {
      title: '机器人编码',
      dataIndex: 'robotCode',
      copyable: true,
      sorter: true,
    },
    {
      title: '机器人名称',
      dataIndex: 'robotName',
      copyable: true,
      sorter: true,
    },
    {
      title: '机器人密钥',
      dataIndex: 'robotSecret',
      copyable: true,
      search: false,
      sorter: true,
    },
    {
      title: '操作',
      key: 'option',
      valueType: 'option',
      render: (text, record) => (
        <AddAppRobot
          setOpen={setOpen}
          actionRef={parentActionRef}
          appId={appId}
          robotCodes={[record?.robotCode as string]}
        />
      ),
    },
  ];

  return (
    <Modal
      title="可添加的机器人列表"
      open={open}
      onCancel={() => setOpen(false)}
      footer={false}
      destroyOnClose
      width={'100%'}
    >
      <ProTable<TableListItem>
        headerTitle="机器人列表"
        rowKey="robotCode"
        actionRef={actionRef}
        columns={columns}
        pagination={{
          showQuickJumper: true,
          defaultPageSize: 10,
        }}
        search={{
          layout: 'vertical',
        }}
        request={getDataSource}
        rowSelection={{
          selections: [Table.SELECTION_ALL, Table.SELECTION_INVERT, Table.SELECTION_NONE],
        }}
        tableAlertRender={({ selectedRowKeys }) => <span>已选 {selectedRowKeys.length} 项</span>}
        tableAlertOptionRender={({ selectedRowKeys }) => (
          <AddAppRobot
            key="add"
            setOpen={setOpen}
            actionRef={parentActionRef}
            appId={appId}
            robotCodes={selectedRowKeys as string[]}
          />
        )}
      />
    </Modal>
  );
};

export default AvailableRobot;
