import { App, Button, Popconfirm } from 'antd';
import type { MutableRefObject } from 'react';
import React from 'react';
import { ActionType } from '@ant-design/pro-components';
import { deleteAppRobot } from '@/services/api/appRobot';

/** 删除应用机器人组件 */
const DeleteAppRobot: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 应用编码 */
  appId: string;
  /** 机器人编码列表 */
  robotCodes: string[];
}> = ({ actionRef, appId, robotCodes }) => {
  const { message } = App.useApp();

  const onConfirm = async () => {
    try {
      await deleteAppRobot({ appId, robotCodes });
      message.success('删除成功');
      actionRef.current?.reload();
      actionRef.current?.clearSelected?.();
      return Promise.resolve();
    } catch (e) {
      return Promise.reject();
    }
  };

  return (
    <Popconfirm title="确定删除？" onConfirm={onConfirm}>
      <Button danger>删除</Button>
    </Popconfirm>
  );
};

export default DeleteAppRobot;
