import { App, Button, Popconfirm } from 'antd';
import type { MutableRefObject } from 'react';
import React from 'react';
import { ActionType } from '@ant-design/pro-components';
import { enableAppTask } from '@/services/api/appTask';

/** 启用应用任务组件 */
const EnableAppTask: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 任务id */
  taskId: string;
}> = ({ actionRef, taskId }) => {
  const { message } = App.useApp();

  const onConfirm = async () => {
    try {
      await enableAppTask({ taskId });
      message.success('启用成功');
      actionRef.current?.reload();
      return Promise.resolve();
    } catch (e) {
      return Promise.reject();
    }
  };

  return (
    <Popconfirm title="确定启用？" onConfirm={onConfirm}>
      <Button type={'primary'}>启用</Button>
    </Popconfirm>
  );
};

export default EnableAppTask;
