import { App, Button, Popconfirm } from 'antd';
import type { MutableRefObject } from 'react';
import React from 'react';
import { ActionType } from '@ant-design/pro-components';
import { stopAppTask } from '@/services/api/appTask';

/** 停止应用任务组件 */
const StopAppTask: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
  /** 任务id */
  taskId: string;
}> = ({ actionRef, taskId }) => {
  const { message } = App.useApp();

  const onConfirm = async () => {
    try {
      await stopAppTask({ taskId });
      message.success('停止成功');
      actionRef.current?.reload();
      return Promise.resolve();
    } catch (e) {
      return Promise.reject();
    }
  };

  return (
    <Popconfirm title="确定停止？" onConfirm={onConfirm}>
      <Button danger>停止</Button>
    </Popconfirm>
  );
};

export default StopAppTask;
