import React, { MutableRefObject } from 'react';
import { App, Button } from 'antd';
import { ActionType, ModalForm, ProFormText } from '@ant-design/pro-components';
import { addRobot } from '@/services/api/robot';
import { whitespaceForbidden } from '@/constants/rules';

/** 添加机器人组件 */
const AddRobot: React.FC<{
  /** Table action 的引用，便于自定义触发 */
  actionRef: MutableRefObject<ActionType | undefined>;
}> = ({ actionRef }) => {
  const { message } = App.useApp();
  /** 提交数据 */
  const onFinish = async (values: any) => {
    await addRobot(values);
    message.success('添加成功');
    actionRef.current?.reload();
    return true;
  };

  return (
    <ModalForm
      title="添加机器人"
      onFinish={onFinish}
      trigger={<Button type="primary">添加</Button>}
    >
      <ProFormText
        name="robotName"
        label="机器人名称"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
      />
      <ProFormText
        name="robotCode"
        label="机器人编码"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
      />
      <ProFormText
        name="robotSecret"
        label="机器人密钥"
        rules={[
          {
            required: true,
          },
          whitespaceForbidden,
        ]}
      />
    </ModalForm>
  );
};

export default AddRobot;
