declare namespace API {
  type AddAppDto = {
    /** 应用名称 */
    appName: string;
    /** 应用编码 */
    appId: string;
  };

  type AddAppRobotCommandDto = {
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode: string;
    /** 命令 */
    command: string;
    /** 应用方接口 */
    url: string;
    /** 说明 */
    description?: string;
  };

  type AddAppRobotDto = {
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCodes: string[];
  };

  type AddAppSftpDto = {
    /** 应用编码 */
    appId: string;
    /** sftp id */
    sftpId: string;
    /** 主机 */
    host: string;
    /** 端口 */
    port: number;
    /** 用户名 */
    username: string;
    /** 密码 */
    password: string;
  };

  type AddAppTaskDto = {
    /** 应用编码 */
    appId: string;
    /** 任务名称 */
    taskName: string;
    /** 任务描述 */
    description?: string;
    /** cron表达式 */
    cron: string;
    /** 机器人编码 */
    robotCode: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId: string;
    /** 数据文件夹 */
    dataDir: string;
    /** 文件名匹配正则表达式 */
    filePattern: string;
  };

  type AddRobotDto = {
    /** 机器人编码 */
    robotCode: string;
    /** 机器人密钥 */
    robotSecret: string;
    /** 机器人名称 */
    robotName: string;
  };

  type AppTaskLogPo = {
    /** 日志id */
    id?: string;
    /** 任务id */
    taskId?: string;
    /** 任务名称 */
    taskName?: string;
    /** 应用编码 */
    appId?: string;
    /** 应用名称 */
    appName?: string;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType?: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId?: string;
    /** sftp ip */
    host?: string;
    /** sftp端口 */
    port?: number;
    /** 数据文件夹 */
    dataDir?: string;
    /** 文件名匹配正则表达式 */
    filePattern?: string;
    /** 文件路径 */
    filePath?: string;
    /** 任务执行状态，0失败1成功 */
    status?: number;
    /** 详情 */
    detail?: string;
    /** 执行时间 */
    createTime?: string;
  };

  type BatchRecallOtoMessagesDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 消息唯一标识列表，每次最多传20个，在发送消息24小时内可以通过processQueryKey撤回消息，超过24小时则无法撤回消息 */
    processQueryKeys: string[];
  };

  type BatchRecallOtoMessagesVo = {
    /** 撤回成功的消息发送任务ID列表 */
    successResult?: string[];
    /** 撤回失败的消息发送任务ID列表及对应的失败原因 */
    failedResult?: Record<string, any>;
  };

  type BatchSendOtoSampleFileDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 媒体文件上传后获取的唯一标识 */
    mediaId: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
    /** 文件名 */
    filename: string;
  };

  type BatchSendOtoSampleImageMsgDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 媒体文件上传后获取的唯一标识 */
    mediaId: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
  };

  type BatchSendSampleMarkdownDto = {
    /** 标题 */
    title: string;
    /** 内容 */
    text: string;
    /** 机器人的编码 */
    robotCode: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
  };

  type BatchSendSampleTextDto = {
    /** 内容 */
    content: string;
    /** 机器人的编码 */
    robotCode: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
  };

  type BatchSendVo = {
    /** 消息id，根据此id，可用于查询消息是否已读和撤回消息 */
    processQueryKey?: string;
    /** 失败的手机号列表和对应原因 */
    failPhones?: Record<string, any>;
    /** 无效的用户userId列表 */
    invalidStaffIdList?: string[];
    /** 被限流的userId列表 */
    flowControlledStaffIdList?: string[];
  };

  type DeleteAppDto = {
    /** 应用编码 */
    appId: string;
  };

  type DeleteAppRobotCommandDto = {
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode: string;
    /** 命令 */
    command: string;
  };

  type DeleteAppRobotDto = {
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCodes: string[];
  };

  type DeleteAppSftpDto = {
    /** sftp id */
    sftpId: string;
  };

  type DeleteAppTaskDto = {
    /** 任务id */
    taskId: string;
  };

  type DeleteRobotDto = {
    /** 机器人编码 */
    robotCode: string;
  };

  type EnableAppTaskDto = {
    /** 任务id */
    taskId: string;
  };

  type GetAppRobotOptionsDto = {
    /** 应用编码 */
    appId: string;
  };

  type GetAppRobotOptionsVo = {
    /** 机器人编码 */
    value?: string;
    /** 机器人名称 */
    label?: string;
  };

  type GetAppSftpOptionsDto = {
    /** 应用编码 */
    appId: string;
  };

  type GetAppSftpOptionsVo = {
    /** sftp id */
    value?: string;
    /** sftp信息 */
    label?: string;
  };

  type GetUserIdByMobileDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 用户的手机号 */
    mobile: string;
  };

  type GetUserIdByMobileVo = {
    /** 员工的userId */
    userId?: string;
  };

  type GroupSendSampleFileDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
    /** 媒体文件上传后获取的唯一标识 */
    mediaId: string;
    /** 文件名 */
    filename: string;
  };

  type GroupSendSampleImageMsgDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
    /** 媒体文件上传后获取的唯一标识 */
    mediaId: string;
  };

  type GroupSendSampleMarkdownDto = {
    /** 标题 */
    title: string;
    /** 内容 */
    text: string;
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
  };

  type GroupSendSampleTextDto = {
    /** 内容 */
    content: string;
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
  };

  type GroupSendVo = {
    /** 加密消息id，根据此id可查询消息已读状态和撤回消息 */
    processQueryKey?: string;
  };

  type ListAppDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用名称 */
    appName?: string;
    /** 应用编码 */
    appId?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppRobotCommandDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode: string;
    /** 命令 */
    command?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppRobotCommandVo = {
    /** 命令 */
    command?: string;
    /** 应用方接口 */
    url?: string;
    /** 说明 */
    description?: string;
    /** 创建时间 */
    createTime?: string;
    /** 更新时间 */
    updateTime?: string;
  };

  type ListAppRobotDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppRobotVo = {
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人密钥 */
    robotSecret?: string;
    /** 机器人名称 */
    robotName?: string;
  };

  type ListAppSftpDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用编码 */
    appId: string;
    /** sftp id */
    sftpId?: string;
    /** 主机 */
    host?: string;
    /** 端口 */
    port?: number;
    /** 用户名 */
    username?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppSftpVo = {
    /** sftp id */
    sftpId?: string;
    /** 应用编码 */
    appId?: string;
    /** 主机 */
    host?: string;
    /** 端口 */
    port?: number;
    /** 用户名 */
    username?: string;
    /** 密码 */
    password?: string;
    /** 创建时间 */
    createTime?: string;
    /** 更新时间 */
    updateTime?: string;
  };

  type ListAppTaskDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用编码 */
    appId: string;
    /** 任务id */
    taskId?: string;
    /** 任务名称 */
    taskName?: string;
    /** 任务状态，0已停止1运行中2已删除 */
    status?: number;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType?: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId?: string;
    /** 主机 */
    host?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppTaskLogDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 日志id */
    id?: string;
    /** 应用编码 */
    appId?: string;
    /** 应用名称 */
    appName?: string;
    /** 任务id */
    taskId?: string;
    /** 任务名称 */
    taskName?: string;
    /** 任务执行状态，0失败1成功 */
    status?: number;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType?: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId?: string;
    /** 主机 */
    host?: string;
    /** 开始时间 */
    startTime?: string;
    /** 结束时间 */
    endTime?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAppTaskVo = {
    /** 应用编码 */
    appId?: string;
    /** 应用名称 */
    appName?: string;
    /** 任务id */
    taskId?: string;
    /** 任务名称 */
    taskName?: string;
    /** 任务描述 */
    description?: string;
    /** 任务状态，0已停止1运行中2已删除 */
    status?: number;
    /** cron表达式 */
    cron?: string;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType?: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId?: string;
    /** 主机 */
    host?: string;
    /** 数据文件夹 */
    dataDir?: string;
    /** 文件名匹配正则表达式 */
    filePattern?: string;
    /** 创建时间 */
    createTime?: string;
    /** 更新时间 */
    updateTime?: string;
  };

  type ListAppVo = {
    /** 应用编码 */
    appId?: string;
    /** 应用名称 */
    appName?: string;
    /** 应用密钥 */
    appSecret?: string;
    /** 创建时间 */
    createTime?: string;
    /** 更新时间 */
    updateTime?: string;
  };

  type ListAvailableRobotDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListAvailableRobotVo = {
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人密钥 */
    robotSecret?: string;
    /** 机器人名称 */
    robotName?: string;
  };

  type ListRobotDto = {
    /** 页码>=1 */
    current: number;
    /** 每页个数，[1,100] */
    pageSize: number;
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 排序 */
    sort?: Record<string, any>;
  };

  type ListRobotVo = {
    /** 机器人编码 */
    robotCode?: string;
    /** 机器人密钥 */
    robotSecret?: string;
    /** 机器人名称 */
    robotName?: string;
    /** 创建时间 */
    createTime?: string;
    /** 更新时间 */
    updateTime?: string;
  };

  type LoginDto = {
    /** 用户名 */
    username: string;
    /** 密码 */
    password: string;
  };

  type loginParams = {
    dto: LoginDto;
  };

  type LoginVo = {
    /** 用户名 */
    name?: string;
    /** 头像 */
    avatar?: string;
  };

  type PageVoAppTaskLogPo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: AppTaskLogPo[];
  };

  type PageVoListAppRobotCommandVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAppRobotCommandVo[];
  };

  type PageVoListAppRobotVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAppRobotVo[];
  };

  type PageVoListAppSftpVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAppSftpVo[];
  };

  type PageVoListAppTaskVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAppTaskVo[];
  };

  type PageVoListAppVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAppVo[];
  };

  type PageVoListAvailableRobotVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListAvailableRobotVo[];
  };

  type PageVoListRobotVo = {
    /** 总数 */
    total?: number;
    /** 列表 */
    list?: ListRobotVo[];
  };

  type RBatchRecallOtoMessagesVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: BatchRecallOtoMessagesVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RBatchSendVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: BatchSendVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RecallGroupMessagesDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
    /** 消息唯一标识列表，每次最多传20个，在发送消息24小时内可以通过processQueryKey撤回消息，超过24小时则无法撤回消息 */
    processQueryKeys: string[];
  };

  type RecallGroupMessagesVo = {
    /** 撤回成功的消息发送任务ID列表 */
    successResult?: string[];
    /** 撤回失败的消息发送任务ID列表及对应的失败原因 */
    failedResult?: Record<string, any>;
  };

  type ResetAppSecretDto = {
    /** 应用编码 */
    appId: string;
  };

  type RGetUserIdByMobileVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: GetUserIdByMobileVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RGroupSendVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: GroupSendVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RListGetAppRobotOptionsVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    /** 数据 */
    data?: GetAppRobotOptionsVo[];
    /** 请求跟踪id */
    traceId?: string;
  };

  type RListGetAppSftpOptionsVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    /** 数据 */
    data?: GetAppSftpOptionsVo[];
    /** 请求跟踪id */
    traceId?: string;
  };

  type RLoginVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: LoginVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RObject = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    /** 数据 */
    data?: Record<string, any>;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoAppTaskLogPo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoAppTaskLogPo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAppRobotCommandVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAppRobotCommandVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAppRobotVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAppRobotVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAppSftpVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAppSftpVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAppTaskVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAppTaskVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAppVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAppVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListAvailableRobotVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListAvailableRobotVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RPageVoListRobotVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: PageVoListRobotVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RRecallGroupMessagesVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: RecallGroupMessagesVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type RunAppTaskDto = {
    /** 任务id */
    taskId: string;
  };

  type RUploadVo = {
    /** 是否成功 */
    success?: boolean;
    /** 错误码 */
    code?: number;
    /** 提示信息 */
    message?: string;
    data?: UploadVo;
    /** 请求跟踪id */
    traceId?: string;
  };

  type SftpBatchSendOtoSampleFileDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** sftp id */
    sftpId: string;
    /** 文件绝对路径 */
    filePath: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
  };

  type SftpBatchSendOtoSampleImageMsgDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** sftp id */
    sftpId: string;
    /** 图片绝对路径 */
    filePath: string;
    /** 接收机器人消息的用户的手机号列表，每次最多传20个 */
    phones?: string[];
    /** 接收机器人消息的用户的userId列表，每次最多传20个 */
    userIds?: string[];
  };

  type SftpGroupSendSampleFileDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
    /** sftp id */
    sftpId: string;
    /** 文件绝对路径 */
    filePath: string;
  };

  type SftpGroupSendSampleImageMsgDto = {
    /** 机器人的编码 */
    robotCode: string;
    /** 会话ID */
    openConversationId: string;
    /** sftp id */
    sftpId: string;
    /** 图片绝对路径 */
    filePath: string;
  };

  type StopAppTaskDto = {
    /** 任务id */
    taskId: string;
  };

  type UpdateAppDto = {
    /** 应用名称 */
    appName: string;
    /** 应用编码 */
    appId: string;
  };

  type UpdateAppRobotCommandDto = {
    /** 应用编码 */
    appId: string;
    /** 机器人编码 */
    robotCode: string;
    /** 命令 */
    command: string;
    /** 应用方接口 */
    url: string;
    /** 说明 */
    description?: string;
  };

  type UpdateAppSftpDto = {
    /** 应用编码 */
    appId: string;
    /** sftp id */
    sftpId: string;
    /** 主机 */
    host: string;
    /** 端口 */
    port: number;
    /** 用户名 */
    username: string;
    /** 密码 */
    password: string;
  };

  type UpdateAppTaskDto = {
    /** 应用编码 */
    appId: string;
    /** 任务名称 */
    taskName: string;
    /** 任务描述 */
    description?: string;
    /** cron表达式 */
    cron: string;
    /** 机器人编码 */
    robotCode: string;
    /** 会话类型：1：单聊，2：群聊 */
    conversationType: number;
    /** 群id */
    openConversationId?: string;
    /** 接收机器人消息的用户的手机号列表 */
    phones?: string;
    /** 接收机器人消息的用户的userId列表 */
    userIds?: string;
    /** sftp id */
    sftpId: string;
    /** 数据文件夹 */
    dataDir: string;
    /** 文件名匹配正则表达式 */
    filePattern: string;
    /** 任务id */
    taskId: string;
  };

  type UpdateRobotDto = {
    /** 机器人编码 */
    robotCode: string;
    /** 机器人密钥 */
    robotSecret: string;
    /** 机器人名称 */
    robotName: string;
  };

  type UploadVo = {
    /** 媒体文件上传后获取的唯一标识 */
    mediaId?: string;
  };
}
